#!/bin/bash


# GUI Wrapper for DEEDS written by M. Heinrich using Pashua of C. Bluem
#


# Wrapper function for interfacing to Pashua. Written by Carsten
# Bluem <carsten@bluem.net> in 10/2003, modified in 12/2003 (including
# a code snippet contributed by Tor Sigurdsson), 08/2004 and 12/2004.
# As 1st argument, you must pass a configuration string
# As 2nd argument, you may pass the encoding to use (see documentation)
# As 3rd argument, you may pass the path to the Pashua application,
#                  if it's not in one of the standard locations.
pashua_run() {

	# Write config file
	pashua_configfile=`/usr/bin/mktemp /tmp/pashua_XXXXXXXXX`
	echo "$1" > $pashua_configfile

	# Find Pashua binary. We do search both . and dirname "$0"
	# , as in a doubleclickable application, cwd is /
	# BTW, all these quotes below are necessary to handle paths
	# containing spaces.
	bundlepath="Pashua.app/Contents/MacOS/Pashua"
	if [ "$3" = "" ]
	then
		mypath=`dirname "$0"`
		for searchpath in "$mypath/Pashua" "$mypath/$bundlepath" "./$bundlepath" \
						  "/Applications/$bundlepath" "$HOME/Applications/$bundlepath"
		do
			if [ -f "$searchpath" -a -x "$searchpath" ]
			then
				pashuapath=$searchpath
				break
			fi
		done
	else
		# Directory given as argument
		pashuapath="$3/$bundlepath"
	fi

	if [ ! "$pashuapath" ]
	then
		echo "Error: Pashua could not be found"
		exit 1
	fi

	# Manage encoding
	if [ "$2" = "" ]
	then
		encoding=""
	else
		encoding="-e $2"
	fi

	# Get result
	result=$("$pashuapath" $encoding $pashua_configfile | perl -pe 's/ /;;;/g;')

	# Remove config file
	rm $pashua_configfile

	# Parse result
	for line in $result
	do
		key=$(echo $line | sed 's/^\([^=]*\)=.*$/\1/')
		value=$(echo $line | sed 's/^[^=]*=\(.*\)$/\1/' | sed 's/;;;/ /g')
		varname=$key
		varvalue="$value"
		eval $varname='$varvalue'
	done

} # pashua_run()


# Define what the dialog should be like
# Take a look at Pashua's Readme file for more info on the syntax

conf="
# Set transparency: 0 is transparent, 1 is opaque
*.transparency=1#0.95

# Set window title
*.title = dense displacement sampling - 3D MRF-based image registration

# Introductory text
tb.type = text
tb.default = This GUI calls the command line tool deeds and passes the selected options. Two input volumes and and output filestem are mandatory, the other settings can be left to default.
tb.height = 276
tb.width = 310
tb.x = 340
tb.y = 44


# Add a filesystem browsers
ob.type = openbrowser
ob.label = Fixed image (nifti-Files only)
ob.width=300
ob.x=10
ob.y=400

ob1.type = openbrowser
ob1.label = Moving image (nifti-Files only)
ob1.width=300
ob1.x=350
ob1.y=400

ob2.type = openbrowser
ob2.label = Output folder
ob2.width=300
ob2.x=10
ob2.y=350

# Add text fields
tx1.type = textfield
tx1.label = Output filename (without ending)
tx1.default = outputname
tx1.width = 200
tx1.x = 350
tx1.y = 350

tx2.type = textfield
tx2.label = Grid-point spacings (voxels)
tx2.default = 8x6x4x3x2
tx2.width = 200
tx2.x=10
tx2.y=270

tx2a.type = textfield
tx2a.label = Radius of search space (units)
tx2a.default = 6x5x4x3x2
tx2a.width = 200
tx2a.x=250
tx2a.y=270

tx2b.type = textfield
tx2b.label = Quantisation of search units (vox)
tx2b.default = 3x2x2x1x1
tx2b.width = 200
tx2b.x=490
tx2b.y=270


# Add a popup menu
pop.type = popup
pop.label = Similarity metric
pop.width = 250
pop.option = self-similarity-context
pop.option = sum-of-absolute-differences
pop.default = self-similarity-context
pop.x=10
pop.y=196


# Add a text field
tx3.type = textfield
tx3.label = Regularisation value alpha
tx3.default = 2.0
tx3.width = 100
tx3.x=300
tx3.y=200

# Add a text field
#tx3b.type = textfield
#tx3b.label = Number of samples per node
#tx3b.default = 50
#tx3b.width = 100
#tx3b.x=490
#tx3b.y=200

# Add a checkbox
chk1.type = checkbox
chk1.label = use symmetric constraint (recommended)
chk1.x = 10
chk1.y = 145
chk1.default = 1

ob3.type = openbrowser
ob3.label = Label volume to apply transform to (optional)
ob3.width=300
ob3.x=350
ob3.y=140

# Add a cancel button with default label
cb.type=cancelbutton
"

# Set the images' paths relative to this file's path / 
# skip images if they can not be found in this file's path
#bgimg=$(dirname "$0")'/bg2.png'

#if [ -e "$bgimg" ]
#then
# 	# Display background image
#	conf="$conf
#	      bg.type = image
#        bg.x = 30
#    bg.y = 2
#	      bg.path = $bgimg"
#fi

#echo "$conf"
pashua_run "$conf" 'utf8'
#|($ob1=='')|($ob2=='')
echo "Calling deeds tmiSSC with the following variables:"
#echo "  -F $ob -M $ob1 -O $ob2/$tx1 -a $tx3 -s $chk1 -G $tx2 -L $tx2a -Q $tx2b"
echo ""
ssc=self-similarity-context
if [ -z "$ob3" ]; then
outseg=""
else
outseg="-S $ob3"
fi
if [ $pop == $ssc ] ; then
nameexec=$(dirname "$0")'/tmiSSC'
else
nameexec=$(dirname "$0")'/tmiSAD'
fi
if [ -z "$ob" ]|[ -z "$ob1" ]|[ -z "$ob2"]; then
CALL="$nameexec -h"
else
CALL="$nameexec -F $ob -M $ob1 -O $ob2/$tx1 -a $tx3 -s $chk1 -G $tx2 -L $tx2a -Q $tx2b $outseg"
fi
echo "$CALL"
$CALL
